@@ -3,11 +3,14 @@
 # Author: Thamme Gowda [tg (at) isi (dot) edu] 
 # Created: 4/8/20
 
-from typing import Tuple, List, Optional, Set, Union
-from dataclasses import dataclass, field
+from typing import Tuple, List, Optional, Union, Any
+from dataclasses import dataclass
+
+
 from mtdata import log
 from mtdata.iso.bcp47 import BCP47Tag, bcp47
 
+
 DID_DELIM = '-'  # I  wanted to use ":", but Windows, they dont like ":" in path! :(
 
 LangPair = Tuple[BCP47Tag, BCP47Tag]
@@ -72,7 +75,7 @@ class Entry:
     __slots__ = ('did', 'url', 'filename', 'ext', 'in_paths', 'in_ext', 'cite', 'cols', 'is_archive')
 
     def __init__(self, did: DatasetId,
-                 url: str,
+                 url: Union[str, Tuple[str, str]],
                  filename: Optional[str] = None,
                  ext: Optional[str] = None,
                  in_paths: Optional[List[str]] = None,
@@ -84,17 +87,18 @@ class Entry:
         self.did = did
         self.url = url
         self.filename = filename
-        orig_name = self.url.split('/')[-1]
         self.ext = ext
         if not self.ext:
             from mtdata.parser import detect_extension
+            assert isinstance(self.url, str), '"ext" attribute must be explicitely set for multi-URL entries'
+            orig_name = self.url.split('/')[-1]
             self.ext = detect_extension(filename or orig_name)
         self.filename = self.filename or f'{self.did.name}.{self.ext}'
 
         self.in_paths = in_paths
         self.in_ext = in_ext
         self.cite = cite
-        self.cols = cols
+        self.cols = cols   # column index starts from zero
 
         assert not self.ext.startswith("."), f'ext {self.ext} should not start with a dot (.)'
         self.is_archive = self.ext in ('zip', 'tar', 'tar.gz', 'tgz')
