@@ -4,7 +4,6 @@
 # Created: 4/4/20
 import argparse
 from pathlib import Path
-from typing import List
 from collections import defaultdict
 
 import mtdata
@@ -12,20 +11,24 @@ from mtdata import log, __version__, cache_dir as CACHE_DIR, cached_index_file
 from mtdata.entry import DatasetId, lang_pair
 from mtdata.utils import IO
 
+DEF_N_JOBS = 1
 
-def list_data(langs, names, not_names=None, full=False):
+
+def list_data(langs, names, not_names=None, full=False, groups=None, not_groups=None, id_only=False):
     from mtdata.index import get_entries
-    entries = get_entries(langs, names, not_names, fuzzy_match=True)
-    log.info(f"Found {len(entries)}")
+    entries = get_entries(langs, names, not_names, groups=groups, not_groups=not_groups, fuzzy_match=True)
     for i, ent in enumerate(entries):
-        print(ent.format(delim='\t'))
+        if id_only:
+            print(ent.did)
+        else:
+            print(ent.format(delim='\t'))
         if full:
             print(ent.cite or "CITATION_NOT_LISTED", end='\n\n')
-    print(f"Total {len(entries)} entries")
+    log.info(f"Total {len(entries)} entries")
 
 
 def get_data(langs, out_dir, train_dids=None, test_dids=None, dev_dids=None, merge_train=False, compress=False,
-             drop_dupes=False, drop_tests=False, **kwargs):
+             drop_dupes=False, drop_tests=False, fail_on_error=False, n_jobs=DEF_N_JOBS, **kwargs):
     if kwargs:
         log.warning(f"Args are ignored: {kwargs}")
     from mtdata.data import Dataset
@@ -33,7 +36,7 @@ def get_data(langs, out_dir, train_dids=None, test_dids=None, dev_dids=None, mer
     dataset = Dataset.prepare(
         langs, train_dids=train_dids, test_dids=test_dids, out_dir=out_dir,
         dev_dids=dev_dids, cache_dir=CACHE_DIR, merge_train=merge_train, compress=compress,
-        drop_dupes=drop_dupes, drop_tests=drop_tests)
+        drop_dupes=drop_dupes, drop_tests=drop_tests, fail_on_error=fail_on_error, n_jobs=n_jobs)
     cli_sig = f'-l {"-".join(str(l) for l in langs)}'
     for flag, dids in [('-tr', train_dids), ('-ts', test_dids), ('-dv', dev_dids)]:
         if dids:
@@ -78,7 +81,8 @@ def list_recipes():
     print_all(RECIPES.values())
 
 
-def get_recipe(recipe_id, out_dir: Path, compress=False, drop_dupes=False, drop_tests=False, **kwargs):
+def get_recipe(recipe_id, out_dir: Path, compress=False, drop_dupes=False, drop_tests=False, fail_on_error=False,
+               n_jobs=DEF_N_JOBS, merge_train=True, **kwargs):
     if kwargs:
         log.warning(f"Args are ignored: {kwargs}")
     from mtdata.recipe import RECIPES
@@ -87,7 +91,8 @@ def get_recipe(recipe_id, out_dir: Path, compress=False, drop_dupes=False, drop_
         raise ValueError(f'recipe {recipe_id} not found. See "mtdata list-recipe"')
 
     get_data(langs=recipe.langs, train_dids=recipe.train, dev_dids=recipe.dev, test_dids=recipe.test,
-             merge_train=True, out_dir=out_dir, compress=compress, drop_dupes=drop_dupes, drop_tests=drop_tests)
+             merge_train=merge_train, out_dir=out_dir, compress=compress, drop_dupes=drop_dupes, drop_tests=drop_tests,
+             fail_on_error=fail_on_error, n_jobs=n_jobs)
 
 
 def show_stats(*dids: DatasetId):
@@ -117,9 +122,10 @@ def add_boolean_arg(parser: argparse.ArgumentParser, name, dest=None, default=Fa
 
 
 def parse_args():
-    p = argparse.ArgumentParser(formatter_class=MyFormatter, epilog=f'Loaded from {__file__} (v{__version__})')
+    my_path = str(Path(__file__).parent)
+    p = argparse.ArgumentParser(formatter_class=MyFormatter, epilog=f'Loaded from {my_path} (v{__version__})')
     p.add_argument('-vv', '--verbose', action='store_true', help='verbose mode')
-    p.add_argument('-v', '--version', action='version', version=f'%(prog)s {__version__}')
+    p.add_argument('-v', '--version', action='version', version=f'%(prog)s {__version__} \n{my_path}')
     p.add_argument('-ri', '--reindex', action='store_true',
                    help=f"Invalidate index of entries and recreate it. This deletes"
                         f" {cached_index_file} only and not the downloaded files. "
@@ -137,19 +143,22 @@ def parse_args():
     list_p = sub_ps.add_parser('list', formatter_class=MyFormatter)
     list_p.add_argument('-l', '--langs', metavar='L1-L2', type=lang_pair,
                         help='Language pairs; e.g.: deu-eng')
+    list_p.add_argument('-id', '--id', action='store_true', help="Show dataset ID only", default=False)
     list_p.add_argument('-n', '--names', metavar='NAME', nargs='*',
                         help='Name of dataset set; eg europarl_v9.')
     list_p.add_argument('-nn', '--not-names', metavar='NAME', nargs='*', help='Exclude these names')
+    list_p.add_argument('-g', '--groups', metavar='GROUP', nargs='*', help='Only select datasets from these groups')
+    list_p.add_argument('-ng', '--not-groups', metavar='GROUP', nargs='*', help='Exclude these groups')
     list_p.add_argument('-f', '--full', action='store_true', help='Show Full Citation')
-    list_p.add_argument('-o', '--out', type=Path, help='This arg is ignored. '
-                                                       'Only used in "get" subcommand.')
+    list_p.add_argument('-o', '--out', type=Path, help='This arg is ignored. Only used in "get" subcommand,'
+                                                       ' but added here for convenience of switching b/w get and list')
 
     get_p = sub_ps.add_parser('get', formatter_class=MyFormatter)
     get_p.add_argument('-l', '--langs', metavar='L1-L2', type=lang_pair,
                        help='Language pairs; e.g.: deu-eng', required=True)
     get_p.add_argument('-tr', '--train', metavar='ID', dest='train_dids', nargs='*', type=DatasetId.parse,
                        help='''R|Names of datasets separated by space, to be used for *training*.
-    e.g. -tr Statmt-news_commentary-16-deu-eng europarl_v9 .
+    e.g. -tr Statmt-news_commentary-16-deu-eng.
      To concatenate all these into a single train file, set --merge flag.''')
     get_p.add_argument('-ts', '--test', metavar='ID', dest='test_dids', nargs='*', type=DatasetId.parse,
                        help='''R|Names of datasets separated by space, to be used for *testing*. 
@@ -160,6 +169,9 @@ def parse_args():
                        help='''R|Dataset to be used for development (aka validation).
     e.g. "-dev Statmt-newstest_deen-2017-deu-eng"''')
     add_boolean_arg(get_p, 'merge', dest='merge_train', default=False, help='Merge train into a single file')
+    add_boolean_arg(get_p, 'fail', dest='fail_on_error', default=False,
+                    help='Fail if an error occurs on any one of dataset pars')
+    get_p.add_argument('-j', '--n-jobs', type=int, help="Number of worker jobs", default=DEF_N_JOBS)
 
     def add_getter_args(parser):
         parser.add_argument(f'--compress', action='store_true', default=False, help="Keep the files compressed")
@@ -180,6 +192,9 @@ def parse_args():
     listr_p = sub_ps.add_parser('list-recipe', formatter_class=MyFormatter)
     getr_p = sub_ps.add_parser('get-recipe', formatter_class=MyFormatter)
     getr_p.add_argument('-ri', '--recipe-id', type=str, help='Recipe ID', required=True)
+    getr_p.add_argument('-f', '--fail-on-error', action='store_true', help='Fail on error')
+    getr_p.add_argument('-j', '--n-jobs', type=int, help="Number of worker jobs (processes)", default=DEF_N_JOBS)
+    add_boolean_arg(getr_p, 'merge', dest='merge_train', default=True, help='Merge train into a single file')
     add_getter_args(getr_p)
 
     stats_p = sub_ps.add_parser('stats', formatter_class=MyFormatter)
@@ -199,7 +214,8 @@ def main():
         log.info(f"Invalidate index: {cached_index_file} -> {bak_file}")
         cached_index_file.rename(bak_file)
     if args.task == 'list':
-        list_data(args.langs, args.names, not_names=args.not_names, full=args.full)
+        list_data(args.langs, args.names, not_names=args.not_names, full=args.full,
+                  groups=args.groups, not_groups=args.not_groups, id_only=args.id)
     elif args.task == 'get':
         get_data(**vars(args))
     elif args.task == 'list-recipe':
